/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "Be.h"


_IMPEXP_BE const char *B_EMPTY_STRING = 0;


_IMPEXP_ROOT status_t _get_next_thread_info (team_id tmid, int32 *cookie, thread_info *info, size_t size) { return 0; }


_IMPEXP_ROOT status_t _get_team_usage_info (team_id tmid, int32 who, team_usage_info *ti, size_t size) { return 0; }


/* Team functions */

_IMPEXP_ROOT status_t kill_team (team_id team) { return 0; }

_IMPEXP_ROOT status_t _get_team_info (team_id team, team_info *info, size_t size) { return 0; }

_IMPEXP_ROOT status_t _get_next_team_info (int32 *cookie, team_info *info, size_t size) { return 0; }


/* Semaphore functions */


// set_sem_owner
_IMPEXP_ROOT status_t set_sem_owner (sem_id sem, team_id team)
{
	return 0;
}


// _get_next_sem_info
_IMPEXP_ROOT status_t _get_next_sem_info (team_id team, int32 *cookie, sem_info *info, size_t size)
{
	return 0;
}


/* Time functions */

_IMPEXP_ROOT uint32 real_time_clock (void) { return 0; }

_IMPEXP_ROOT void set_real_time_clock (int32 secs_since_jan1_1970) {}

_IMPEXP_ROOT bigtime_t real_time_clock_usecs (void) { return 0; }

_IMPEXP_ROOT status_t set_timezone(char *str) { return 0; }

_IMPEXP_ROOT bigtime_t system_time (void) { return 0; }

/* Port functions */

_IMPEXP_ROOT port_id create_port(int32 capacity, const char *name) { return 0; }

_IMPEXP_ROOT port_id find_port(const char *name) { return 0; }

_IMPEXP_ROOT status_t write_port(port_id port, int32 code, const void *buf, size_t buf_size) { return 0; }

_IMPEXP_ROOT status_t read_port(port_id port, int32 *code,  void *buf, size_t buf_size) { return 0; }

_IMPEXP_ROOT status_t write_port_etc(port_id port, int32 code,  const void *buf, size_t buf_size, uint32 flags, bigtime_t timeout) { return 0; }

_IMPEXP_ROOT status_t read_port_etc(port_id port, int32 *code, void *buf, size_t buf_size, uint32 flags, bigtime_t timeout) { return 0; }

_IMPEXP_ROOT ssize_t port_buffer_size(port_id port) { return 0; }

_IMPEXP_ROOT ssize_t port_buffer_size_etc(port_id port, uint32 flags, bigtime_t timeout) { return 0; }

_IMPEXP_ROOT ssize_t port_count(port_id port) { return 0; }

_IMPEXP_ROOT status_t set_port_owner(port_id port, team_id team) { return 0; }

_IMPEXP_ROOT status_t close_port(port_id port) { return 0; }

_IMPEXP_ROOT status_t delete_port(port_id port) { return 0; }

_IMPEXP_ROOT status_t _get_port_info(port_id port, port_info *info, size_t size) { return 0; }

_IMPEXP_ROOT status_t _get_next_port_info(team_id team, int32 *cookie, port_info *info, size_t size) { return 0; }

