/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#pragma warning(disable:4786)

#include "Be.h"

/*
extern _IMPEXP_ROOT port_id	create_port(int32 capacity, const char *name);
extern _IMPEXP_ROOT port_id	find_port(const char *name);

extern _IMPEXP_ROOT status_t	write_port(port_id port, int32 code, 
						   					const void *buf, 
						   					size_t buf_size);

extern _IMPEXP_ROOT status_t	read_port(port_id port, int32 *code, 
						  					void *buf, size_t buf_size);

extern _IMPEXP_ROOT status_t	write_port_etc(port_id port, int32 code, 
							   				const void *buf, size_t buf_size,
							   				uint32 flags, bigtime_t timeout);

extern _IMPEXP_ROOT status_t	read_port_etc(port_id port, int32 *code, 
							  				void *buf, size_t buf_size,
        				                    uint32 flags, bigtime_t timeout);

extern _IMPEXP_ROOT ssize_t	port_buffer_size(port_id port);
extern _IMPEXP_ROOT ssize_t	port_buffer_size_etc(port_id port, 
									 		uint32 flags, bigtime_t timeout);

extern _IMPEXP_ROOT ssize_t	port_count(port_id port);
extern _IMPEXP_ROOT status_t	set_port_owner(port_id port, team_id team);

extern _IMPEXP_ROOT status_t	close_port(port_id port);

extern _IMPEXP_ROOT status_t	delete_port(port_id port);

extern _IMPEXP_ROOT status_t	_get_port_info(port_id port, port_info *info,
											size_t size);
extern _IMPEXP_ROOT status_t	_get_next_port_info(team_id team, int32 *cookie, port_info *info, size_t size);
*/